﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.Xml.Linq;
using System.Xml.Serialization;

namespace MediaRss
{
	[XmlRoot(ElementName = "content", Namespace = "http://search.yahoo.com/mrss/")]
	public class Content : MediaRssBase, IXmlSerializable
	{
		internal const string ELEMENT_NAME = "content";
		
		public Uri Url { get; set; }
		public Double FileSize { get; set; }
		public Int32 BitRate { get; set; }
		public String Type { get; set; }
		public String Expression { get; set; }

		#region IXmlSerializable Members

		public void ReadXml(XmlReader reader)
		{
			bool isEmpty = reader.IsEmptyElement;

			if (reader.HasAttributes)
			{
				for (int i = 0; i < reader.AttributeCount; i++)
				{
					reader.MoveToNextAttribute();

					if (reader.NamespaceURI == "")
					{
						if (reader.LocalName == "url")
						{
							Url = new Uri(reader.Value);
						}
						else if (reader.LocalName == "fileSize")
						{
							FileSize = Double.Parse(reader.Value);
						}
						else if (reader.LocalName == "bitrate")
						{
							BitRate = Int32.Parse(reader.Value);
						}
						else if (reader.LocalName == "type")
						{
							Type = reader.Value;
						}
						else if (reader.LocalName == "expression")
						{
							Expression = reader.Value;
						}
						else
						{
							AttributeExtensions.Add(new XmlQualifiedName(reader.LocalName, reader.NamespaceURI), reader.Value);
						}
					}
				}
			}

			reader.ReadStartElement();

			AddElementExtensions(reader,isEmpty);
		}

		public override string ToString()
		{
			var builder = new StringBuilder();
			builder.AppendFormat("Url: {0}\n", Url);
			builder.AppendFormat("FileSize: {0}\n", FileSize);
			builder.AppendFormat("BitRate: {0}\n", BitRate);
			builder.AppendFormat("Type: {0}\n", Type);
			builder.AppendFormat("Expression: {0}\n", Expression);

			if (ElementExtensions.Count > 0)
			{
				foreach (XElement elt in ElementExtensions)
				{
					builder.AppendLine(elt.ToString());
				}
			}
			return builder.ToString();
		}


		public void WriteXml(XmlWriter writer)
		{
			if (Url != null)
			{
				writer.WriteAttributeString("url", null, Url.ToString());
			}

			writer.WriteAttributeString("filesize", null, FileSize.ToString());
			writer.WriteAttributeString("bitrate", null, BitRate.ToString());

			if (Type != null)
			{
				writer.WriteAttributeString("type", null, Type);
			}
			if (Expression != null)
			{
				writer.WriteAttributeString("expression", null, Expression);
			}

			foreach (KeyValuePair<XmlQualifiedName, string> kvp in AttributeExtensions)
			{
				writer.WriteAttributeString(kvp.Key.Name, kvp.Key.Namespace, kvp.Value);
			}

			foreach (XElement element in ElementExtensions)
			{
				element.WriteTo(writer);
			}
		}

		
		#endregion
	}
}