﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Xml;
using System.Xml.Linq;
using System.Xml.Serialization;

namespace MediaRss
{
	[XmlRoot(ElementName = "embed", Namespace = "http://search.yahoo.com/mrss/")]
	public class Embed : MediaRssBase, IXmlSerializable
	{
		internal const string ELEMENT_NAME = "embed";
	
		public Uri Url { get; set; }
		public Int32 Width { get; set; }
		public Int32 Height { get; set; }
		public Collection<Parameter> ParameterItems { get; set; }
		
		public Embed()
		{
			ParameterItems = new Collection<Parameter>();
		}

		#region IXmlSerializable Members

		public void ReadXml(XmlReader reader)
		{
			bool isEmpty = reader.IsEmptyElement;

			if (reader.HasAttributes)
			{
				for (int i = 0; i < reader.AttributeCount; i++)
				{
					reader.MoveToNextAttribute();

					if (reader.NamespaceURI == "")
					{
						if (reader.LocalName == "url")
						{
							Url = new Uri(reader.Value);
						}
						else if (reader.LocalName == "width")
						{
							Width = Int32.Parse(reader.Value);
						}
						else if (reader.LocalName == "height")
						{
							Height = Int32.Parse(reader.Value);
						}
						else
						{
							AttributeExtensions.Add(new XmlQualifiedName(reader.LocalName, reader.NamespaceURI), reader.Value);
						}
					}
				}
			}

			reader.ReadStartElement();

			if (!isEmpty)
			{
				while (reader.IsStartElement())
				{
					switch (reader.LocalName)
					{
						case Parameter.ELEMENT_NAME:
							var param = new Parameter();
							param.ReadXml(reader);
							ParameterItems.Add(param);
							break;
						default:
							ElementExtensions.Add((XElement)XNode.ReadFrom(reader));
							break;
					} 
				}
			}
			reader.ReadEndElement();
		}

		public void WriteXml(XmlWriter writer)
		{
			if (Url != null)
			{
				writer.WriteAttributeString("url", null, Url.ToString());
			}

			writer.WriteAttributeString("width", null, Width.ToString());
			writer.WriteAttributeString("height", null, Height.ToString());

			if (ParameterItems != null && ParameterItems.Count > 0)
			{
				foreach(var param in ParameterItems)
				{
					param.WriteXml(writer);
				}
			}

			foreach (KeyValuePair<XmlQualifiedName, string> kvp in AttributeExtensions)
			{
				writer.WriteAttributeString(kvp.Key.Name, kvp.Key.Namespace, kvp.Value);
			}

			foreach (XElement element in ElementExtensions)
			{
				element.WriteTo(writer);
			}
		}
		#endregion
	}
}